set memory 500m
set matsize 1000

pause on
set more off

use data\consolidated_salestaxandelectiondata.dta

***
*Recode variables
***

*1 in election year, 0 otherwise
gen preselecyear=0
replace preselecyear=1 if (year/4)==int(year/4)

*1 when dem wins, -1 when rep wins, 0 otherwise
gen presdemwin=0
replace presdemwin=-1 if preselecyear==1
replace presdemwin=1 if year==1992 | year==1996

*interact preswinner and partisanship measures
gen dpct2p_8088_demwin=dempres2pavg_8088*presdemwin
gen dpct2p_8000_demwin=dempres2pavg_8000*presdemwin
gen dpct2p_80_demwin=dempres2p_80*presdemwin
gen dpct2p_00_demwin=dempres2p_00*presdemwin
gen dpct2p_9204_demwin=dempres2pavg_9204*presdemwin

label var dpct2p_8088_demwin "Avg. Dem. prop. 2-party Pres. vote 1980-1988 x Pres. win (1=Dem., -1=Rep.)"
label var dpct2p_8000_demwin "Avg. Dem. prop. 2-party Pres. vote 1980-2000 x Pres. win (1=Dem., -1=Rep.)"
label var dpct2p_80_demwin "Dem. prop. 2-party Pres. vote 1980 x Pres. win (1=Dem., -1=Rep.)"
label var dpct2p_00_demwin "Dem. prop. 2-party Pres. vote 2000 x Pres. win (1=Dem., -1=Rep.)"

*year dummies
quietly tab year, gen(yind_)
drop yind_29

***
*Other Interactions with Dem. Win
***

gen logpci_demwin=logpci*presdemwin
gen pci_demwin=pci*presdemwin
gen dw_propblack2000=propblack2000*presdemwin
gen dw_loghhinc1997=loghhinc1997*presdemwin
gen dw_proppov1997=proppov1997*presdemwin
gen dw_propss1999=propss1999*presdemwin
gen dw_educ00=prop25andovercollegeplus*presdemwin
gen dw_logfedfundspercap=logfedfundspercap*presdemwin
gen dw_logtranspercap1998=logtranspercap1998*presdemwin
gen dw_propgov=propgov*presdemwin
gen dwa_logmfgvalueaddpercap1997=logmfgvalueaddpercap1997*presdemwin
gen dw_logfarmsalespercap1997=logfarmsalespercap1997*presdemwin
gen dw_logbankpercap1999=logbankpercap1999*presdemwin
gen dw_metrocty=metrocty*presdemwin
gen dw_mining=mining*presdemwin
gen dw_mfg=mfg*presdemwin
gen dw_reccty=reccty*presdemwin
gen dw_retirecty=retirecty*presdemwin
gen dw_mempercap=mempercap*presdemwin

label var dw_educ00 "Prop. Pop. Age 25+ w/ BA or more 2000 x Pres. Win"
label var dw_propblack2000 "Prop. Pop. Black 2000 x Pres. Win"
label var dw_loghhinc1997 "Log Median Household Income 1997 ($1,000s) x Pres. Win"
label var dw_proppov1997 "Prop. Pop. in Poverty 1997 x Pres. Win"
label var dw_logfedfundspercap "Log Federal Funds and Grants Per Capita 1999 ($1,000s) x Pres. Win"
label var dw_logtranspercap1998 "Log Government Transfers Per Capita 1998 ($1,000s) x Pres. Win"
label var dwa_logmfgvalueaddpercap1997 "Log Manufacturing Value Added Per Capita 1997 ($1,000s) x Pres. Win"
label var dw_logfarmsalespercap1997 "Log Value of Farm Products Sold Per Capita 1997 ($1,000s) x Pres. Win"
label var dw_logbankpercap1999 "Log Banking Deposits Per Capita 1999 ($1,000s) x Pres. Win"
label var dw_propss1999 "Prop. Pop. Receiving Social Security 1999 x Pres. Win"
label var dw_propgov "Prop. Pop. Working for Government (Civilian and Military) 1998 x Pres. Win"
label var dw_metrocty "Metropolitan county x Pres. Win"
label var dw_mining "Mining-dependent county x Pres. Win"
label var dw_mfg "Manufacturing-dependent county x Pres. Win"
label var dw_reccty "Recreation-destination county x Pres. Win"
label var retirecty "Retirement-destination county"
label var dw_retirecty "Retirement-destination county x Pres. Win"
label var dw_mempercap "Church members per capita 1990 x Pres. Win"

***
*Label variables
***

label var pci "Per Capita Income 2000 ($10,000s)"
label var pci_demwin "Per Capita Income 2000 ($10,000s) x Pres. win (1=Dem., -1=Rep.)"

label var logpci "Log Per Capita Income 2000 ($1,000s)"
label var logpci_demwin "Log Per Capita Income 2000 ($1,000s) x Pres. win (1=Dem., -1=Rep.)"

label var fips_st "county/area"

*****************************************************************************************
*Change in difference estimates relative to prior 3 years with county/area fixed effects*
*****************************************************************************************

*Note that these year dummies are only defined for pres-elec years, so sample is automatically restricted to those years
drop yind_*
tab year if preselec==1, gen(yind_)
drop yind_7
rename yind_1 yind_1980
rename yind_2 yind_1984
rename yind_3 yind_1988
rename yind_4 yind_1992
rename yind_5 yind_1996
rename yind_6 yind_2000

label var yind_1980 "Year=1980"
label var yind_1984 "Year=1984"
label var yind_1988 "Year=1988"
label var yind_1992 "Year=1992"
label var yind_1996 "Year=1996"
label var yind_2000 "Year=2000"

*****
*Variable Codings that follow are for placebo-controlled model
*****

*For the Placebo-controlled model, let's look at change in sales in the year before the election as a function of (forward-looking) election outcome
tab year if ((year+1)/4)==int((year+1)/4), gen(ypind_)
drop ypind_7
rename ypind_1 ypind_1979
rename ypind_2 ypind_1983
rename ypind_3 ypind_1987
rename ypind_4 ypind_1991
rename ypind_5 ypind_1995
rename ypind_6 ypind_1999

label var ypind_1979 "Year=1979"
label var ypind_1983 "Year=1983"
label var ypind_1987 "Year=1987"
label var ypind_1991 "Year=1991"
label var ypind_1995 "Year=1995"
label var ypind_1999 "Year=1999"

*1 in year prior to election year, 0 otherwise
gen preselecnextyear=0
replace preselecnextyear=1 if ((year+1)/4)==int((year+1)/4)

*1 when dem will win, -1 when rep will win, 0 otherwise
gen presdemwinnext=0
replace presdemwinnext=-1 if preselecnextyear==1
replace presdemwinnext=1 if year==1991 | year==1995

*interact presdemwinnext and partisanship
gen pct2p_nextdemwin=dempres2pavg_8088*presdemwinnext

*interact presdemwinnext and income
gen logpci_nextdemwin=logpci*presdemwinnext
gen pci_nextdemwin=pci*presdemwinnext

label var logpci_nextdemwin "Log Per Capita Income 2000 ($1,000s) x Pres. win (1=Dem., -1=Rep.) in following year"
label var pct2p_nextdemwin "Dem. prop. 2-party vote 2000 x Pres. win (1=Dem., -1=Rep.) in following year"

/****************************************************************************************
*We want to run these models on places that have at least one dem win and one rep. win.
*The easiest way to do that is to run this code to construct the following data set.
*Note here that we use the 2000 vote, because that allows us to keep Maine and Vermont,
*where we only have sub-county level measures of vote outcomes for 2000.
****************************************************************************************/
   
preserve

quietly xtreg logchg1qfrom3q avg_3yr_log3qto1q yind_1992-yind_2000 dpct2p_9204_demwin if year>=1990, fe i(fipsindx)
gen used=e(sample)
gen dcase=1 if used==1 & (year==1992 | year==1996)
gen rcase=1 if used==1 & (year==2000 | year==2004)
sort fipsindx
replace dcase=0 if dcase==.
replace rcase=0 if rcase==.
sort fipsindx
collapse (max) dcase rcase, by(fipsindx)
gen useme=1 if dcase==1 & rcase==1
replace useme=0 if useme==.
sort fipsindx
drop dcase rcase
rename useme CaseHasOneDandRwin
sort fipsindx
save data\cases_to_use.dta, replace
clear

restore

*Merge back in list of cases with at least one victory by each side

sort fipsindx
joinby fipsindx using data\cases_to_use.dta, unmatched(master)

/****************************************************************************************
****************************************************************************************/

*RUN BASE MODEL TO SET SAMPLE
quietly xtreg logchg1qfrom3q avg_3yr_log3qto1q yind_1992-yind_2000 dpct2p_9204_demwin if year>=1990 & CaseHasOneDandRwin==1 & reservation~=1, fe i(fipsindx) cluster(fipsindx)
drop if e(sample)==0

*get wealthiest and poorest 15% of counties
gen wplace=.
quietly _pctile logpci if year==1996, p(15 85)
replace wplace=1 if logpci>=r(r2) & e(sample)==1
replace wplace=0 if logpci<=r(r1) & e(sample)==1

*id whether county is dem or rep.
gen dplace=.
quietly _pctile dempres2pavg_8088 if wplace==0 & year==1996, p(25 75)
replace dplace=0 if wplace==0 & dempres2pavg_9204<=r(r1)
replace dplace=1 if wplace==0 & dempres2pavg_9204>=r(r2)

quietly _pctile dempres2pavg_8088 if wplace==1 & year==1996, p(25 75)
replace dplace=0 if wplace==1 & dempres2pavg_9204<=r(r1)
replace dplace=1 if wplace==1 & dempres2pavg_9204>=r(r2)

drop if wplace==. | dplace==.

keep year state county logchg1qfrom3q dplace wplace

gen changedemwin=0
replace changedemwin=logchg1qfrom3q if year==1992 | year==1996
gen changerepwin=0
replace changerepwin=logchg1qfrom3q if year==2000 | year==2004
sort state county wplace dplace
collapse (mean)  changedemwin changerepwin, by(state county wplace dplace)
gen changedemminuschangerep=changedemwin-changerepwin

label var wplace "Wealthy or Poor County"
label var dplace "Democratic or Republican County"
label var changedemminuschangerep "Average Log Change in Taxable Sales, Democratic Wins - Republican Wins"
label define clabel 0 "15% Poorest County" 1 "15% Richest County"
label values wplace clabel
label define dlabel 0 "25% Most Republican County" 1 "25% Most Democratic County"
label values dplace dlabel

log using logs\Table5.log, text replace

*poor counties in texas, split between dem and rep
tab dplace wplace if st=="tx"
cl state county wplace dplace if wplace==0 & st=="tx"

*poor counties in va, split between dem and rep
tab dplace wplace if st=="va"
cl state county wplace dplace if wplace==0 & st=="va"

*rich places in florida, split between dem and rep
tab dplace wplace if st=="fl"
cl state county wplace dplace if wplace==1 & st=="fl"

table dplace , c(mean changedemminuschangerep sd changedemminuschangerep n changedemminuschangerep) by(wplace)

codebook changedemminuschangerep

bysort wplace: ttest changedemminuschangerep, by(dplace)

log close
